import { BrowserOptions } from '@sentry/browser';
import { Client } from '@sentry/core';
/**
 * Inits the Svelte SDK
 */
export declare function init(options: BrowserOptions): Client | undefined;
/**
 * Adds a global event processor to detect if the SDK is initialized in a SvelteKit frontend,
 * in which case we add SvelteKit an event.modules entry to outgoing events.
 * SvelteKit detection is performed only once, when the event processor is called for the
 * first time. We cannot perform this check upfront (directly when init is called) because
 * at this time, the HTML element might not yet be accessible.
 */
export declare function detectAndReportSvelteKit(): void;
/**
 * To actually detect a SvelteKit frontend, we search the DOM for a special
 * div that's inserted by SvelteKit when the page is rendered. It's identified
 * by its id, 'svelte-announcer', and it's used to improve page accessibility.
 * This div is not present when only using Svelte without SvelteKit.
 *
 * @see https://github.com/sveltejs/kit/issues/307 for more information
 */
export declare function isSvelteKitApp(): boolean;
//# sourceMappingURL=sdk.d.ts.map
